lupapiste-commons.ring.mongo-session

MongoDB-backed Ring SessionStore

  • Session keys are generated with 256-bit CSPRNG randomness (java.security.SecureRandom) and encoded as URL-safe Base64 (43 characters, no padding).
  • The database stores a SHA-256 hash of the session key as the document _id
MongoDB-backed Ring SessionStore
- Session keys are generated with 256-bit CSPRNG randomness (java.security.SecureRandom)
  and encoded as URL-safe Base64 (43 characters, no padding).
- The database stores a SHA-256 hash of the session key as the document `_id`
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries